.. image:: https://img.shields.io/travis/nonameitem/cool-django-auth-ldap/develop?style=flat-square
   :target: https://travis-ci.org/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/coveralls/github/NoNameItem/cool-django-auth-ldap/develop?style=flat-square
   :target: https://coveralls.io/github/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/readthedocs/cool-django-auth-ldap/develop?style=flat-square
   :target: https://cool-django-auth-ldap.readthedocs.io/en/develop/